Crate derive_builder_apply_to

Crate derive_builder_apply_to 

A procedural macro for generating apply_to methods for builder patterns.

This crate provides the ApplyTo derive macro that generates an apply_to method for builder structs, allowing them to selectively update target structs with only the fields that have been set.

Derive Macros

ApplyTo
Derive macro for generating an apply_to method on builder structs.